@@ -123,10 +123,29 @@ def get_args() -> argparse.Namespace:
         pyproject.toml.""",
     )
 
+    parser.add_argument(
+        "-up",
+        "--update",
+        type=str,
+        default=None,
+        help=""" Excpects one argument: "major", "minor", or "patch".
+        Passing "-up minor" is equivalent to passing the cli string: "-b -t -i -iv minor -uc -ca build -s".
+        To publish the updated package, the -p/--publish switch needs to be added to the cli input.""",
+    )
+
     args = parser.parse_args()
 
     args.package = Path(args.package).resolve()
 
+    if args.update:
+        args.build = True
+        args.tag_version = True
+        args.install = True
+        args.increment_version = args.update
+        args.update_changelog = True
+        args.commit_all = "build"
+        args.sync = True
+
     if args.increment_version and args.increment_version not in [
         "major",
         "minor",
@@ -188,8 +207,7 @@ def main(args: argparse.Namespace = None):
         if args.commit_all == "build":
             version = tomlkit.loads(pyproject_path.read_text())["project"]["version"]
             args.commit_all = f"chore: build v{version}"
-        os.system(f"git add .")
-        os.system(f'git commit -a -m "{args.commit_all}"')
+        os.system(f'git commit -am "{args.commit_all}"')
 
     if args.tag_version:
         hassle_utilities.tag_version(args.package)
@@ -199,7 +217,7 @@ def main(args: argparse.Namespace = None):
 
     if args.install:
         os.system(
-            f"pip install --no-deps -U --no-cache-dir {args.package.stem if args.publish else args.package}"
+            f"pip install {args.package.stem if args.publish else args.package} --no-deps --upgrade --no-cache-dir"
         )
 
     if args.sync:
